# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# The free quota for this month is used up. To continue to use the service, you need to upgrade to a paid account in the TMT console.
FAILEDOPERATION_NOFREEAMOUNT = 'FailedOperation.NoFreeAmount'

# The service is suspended due to overdue payments. Top up your account first.
FAILEDOPERATION_SERVICEISOLATE = 'FailedOperation.ServiceIsolate'

# The service is not activated. Activate it in the TMT console first.
FAILEDOPERATION_USERNOTREGISTERED = 'FailedOperation.UserNotRegistered'

# Internal error.
INTERNALERROR = 'InternalError'

# Backend service timeout. Please try again later.
INTERNALERROR_BACKENDTIMEOUT = 'InternalError.BackendTimeout'

# Unknown error.
INTERNALERROR_ERRORUNKNOWN = 'InternalError.ErrorUnknown'

# Request failed.
INTERNALERROR_REQUESTFAILED = 'InternalError.RequestFailed'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Invalid parameter.
INVALIDPARAMETER_MISSINGPARAMETER = 'InvalidParameter.MissingParameter'

# The quota limit is reached.
LIMITEXCEEDED = 'LimitExceeded'

# The request frequency limit is reached.
LIMITEXCEEDED_LIMITEDACCESSFREQUENCY = 'LimitExceeded.LimitedAccessFrequency'

# Missing parameter.
MISSINGPARAMETER = 'MissingParameter'

# Incorrect name entered in the `Action` field.
UNAUTHORIZEDOPERATION_ACTIONNOTFOUND = 'UnauthorizedOperation.ActionNotFound'

# Unsupported operation.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# The text length limit (2,000 characters) for a request is reached.
UNSUPPORTEDOPERATION_TEXTTOOLONG = 'UnsupportedOperation.TextTooLong'

# Unsupported target language. Please refer to the supported language list.
UNSUPPORTEDOPERATION_UNSUPPORTEDTARGETLANGUAGE = 'UnsupportedOperation.UnSupportedTargetLanguage'

# Unsupported language. Please refer to the supported language list.
UNSUPPORTEDOPERATION_UNSUPPORTEDLANGUAGE = 'UnsupportedOperation.UnsupportedLanguage'

# Unsupported source language. Please refer to the supported language list.
UNSUPPORTEDOPERATION_UNSUPPORTEDSOURCELANGUAGE = 'UnsupportedOperation.UnsupportedSourceLanguage'
